@@ -3,7 +3,7 @@ package CSS::Struct;
 use strict;
 use warnings;
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 1;
 
@@ -44,10 +44,21 @@ CSS::Struct - Struct oriented CSS manipulation.
 
 =head1 SEE ALSO
 
-L<CSS::Struct::Output::Core>,
-L<CSS::Struct::Output::Raw>,
-L<CSS::Struct::Output::Indent>,
-L<CSS::Struct::Utils>.
+=over
+
+=item L<CSS::Struct::Output>
+
+Base class for CSS::Struct::Output::*.
+
+=item L<CSS::Struct::Output::Raw>
+
+Raw printing 'CSS::Struct' structure to CSS code.
+
+=item L<CSS::Struct::Output::Indent>
+
+Indent printing 'CSS::Struct' structure to CSS code.
+
+=back
 
 =head1 AUTHOR
 
@@ -63,6 +74,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
